@@ -20,4 +20,15 @@ def is_a_share(stock_code):
         # 检查股票代码是否以0, 3, 6开头
         if stock_code.startswith(("0", "3", "6")):
             return True
-    return False
\ No newline at end of file
+    return False
+
+
+def gpu_info():
+    import torch
+    # 获取可用的 GPU 数量
+    gpu_count = torch.cuda.device_count()
+    print(f"Available GPUs: {gpu_count}")
+
+    # 列出每个 GPU 的名称
+    for i in range(gpu_count):
+        print(f"GPU {i}: {torch.cuda.get_device_name(i)}")
